@@ -1,3 +1,3 @@
 from .config import Config, read_config, save_config, compile_config, compile_config_parallel, read_config_directly, \
-    read_config_with_system
+    read_config_with_system, save_config_py
 from .utils import parallel_transform, parallel_transform_slurm
