@@ -129,6 +129,26 @@ class Buffer(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def save_data(self, file_name: str):
+        """
+        Overview:
+            Save buffer data into a file.
+        Arguments:
+            - file_name (:obj:`str`): file name of buffer data
+        """
+        raise NotImplementedError
+
+    @abstractmethod
+    def load_data(self, file_name: str):
+        """
+        Overview:
+            Load buffer data from a file.
+        Arguments:
+            - file_name (:obj:`str`): file name of buffer data
+        """
+        raise NotImplementedError
+
     @abstractmethod
     def count(self) -> int:
         raise NotImplementedError
