@@ -1,7 +1,9 @@
+import os
 import itertools
 import random
 import uuid
 from ditk import logging
+import hickle
 from typing import Any, Iterable, List, Optional, Tuple, Union
 from collections import Counter
 from collections import defaultdict, deque, OrderedDict
@@ -209,6 +211,22 @@ class DequeBuffer(Buffer):
         key_value_pairs = zip(remain_indices, range(len(indices)))
         self.indices = BufferIndex(self.storage.maxlen, key_value_pairs)
 
+    def save_data(self, file_name: str):
+        if not os.path.exists(os.path.dirname(file_name)):
+            # If the folder for the specified file does not exist, it will be created.
+            if os.path.dirname(file_name) != "":
+                os.makedirs(os.path.dirname(file_name))
+        hickle.dump(
+            py_obj=(
+                self.storage,
+                self.indices,
+                self.meta_index,
+            ), file_obj=file_name
+        )
+
+    def load_data(self, file_name: str):
+        self.storage, self.indices, self.meta_index = hickle.load(file_name)
+
     def count(self) -> int:
         """
         Overview:
@@ -233,25 +251,6 @@ class DequeBuffer(Buffer):
         self.indices.clear()
         self.meta_index = {}
 
-    def import_data(self, data_with_meta: List[Tuple[Any, dict]]) -> None:
-        """
-        Overview:
-            The method that push data by sequence.
-        Arguments:
-            data_with_meta (List[Tuple[Any, dict]]): The sequence of (data, meta) tuples.
-        """
-        for data, meta in data_with_meta:
-            self._push(data, meta)
-
-    def export_data(self) -> List[BufferedData]:
-        """
-        Overview:
-            The method that export all data in the buffer by sequence.
-        Returns:
-            storage (List[BufferedData]): All ``BufferedData`` objects stored in the buffer.
-        """
-        return list(self.storage)
-
     def _push(self, data: Any, meta: Optional[dict] = None) -> BufferedData:
         index = uuid.uuid1().hex
         if meta is None:
