@@ -72,10 +72,10 @@ def eval(
 
     # Evaluate
     _, episode_info = evaluator.eval()
-    reward = [e['final_eval_reward'] for e in episode_info]
-    eval_reward = np.mean(to_ndarray(reward))
-    print('Eval is over! The performance of your RL policy is {}'.format(eval_reward))
-    return eval_reward
+    reward = [e['eval_episode_return'] for e in episode_info]
+    episode_return = np.mean(to_ndarray(reward))
+    print('Eval is over! The performance of your RL policy is {}'.format(episode_return))
+    return episode_return
 
 
 def collect_demo_data(
@@ -271,8 +271,8 @@ def episode_to_transitions_filter(data_path: str, expert_data_path: str, nstep:
         _dict = pickle.load(f)  # class is list; length is cfg.reward_model.collect_count
     post_process_data = []
     for i in range(len(_dict)):
-        episode_rewards = torch.stack([_dict[i][j]['reward'] for j in range(_dict[i].__len__())], axis=0)
-        if episode_rewards.sum() < min_episode_return:
+        episode_returns = torch.stack([_dict[i][j]['reward'] for j in range(_dict[i].__len__())], axis=0)
+        if episode_returns.sum() < min_episode_return:
             continue
         data = get_nstep_return_data(_dict[i], nstep)
         post_process_data.extend(data)
