@@ -121,7 +121,7 @@ def serial_pipeline(
     import pickle
     import numpy as np
     with open(os.path.join(cfg.exp_name, 'result.pkl'), 'wb') as f:
-        eval_value_raw = [d['final_eval_reward'] for d in eval_info]
+        eval_value_raw = [d['eval_episode_return'] for d in eval_info]
         final_data = {
             'stop': stop,
             'env_step': collector.envstep,
