@@ -122,16 +122,6 @@ class BaseEnvManager(object):
             self._action_space = self._env_ref.action_space
             self._reward_space = self._env_ref.reward_space
             self._env_ref.close()
-        try:
-            global space_log_flag
-            if space_log_flag:
-                logging.info("Env Space Information:")
-                logging.info("\tObservation Space: {}".format(self._observation_space))
-                logging.info("\tAction Space: {}".format(self._action_space))
-                logging.info("\tReward Space: {}".format(self._reward_space))
-                space_log_flag = False
-        except:
-            pass
         self._env_states = {i: EnvState.VOID for i in range(self._env_num)}
         self._env_seed = {i: None for i in range(self._env_num)}
         self._episode_num = self._cfg.episode_num
@@ -203,7 +193,9 @@ class BaseEnvManager(object):
 
     @property
     def method_name_list(self) -> list:
-        return ['reset', 'step', 'seed', 'close', 'enable_save_replay', 'render']
+        return [
+            'reset', 'step', 'seed', 'close', 'enable_save_replay', 'render', 'reward_shaping', 'enable_save_figure'
+        ]
 
     def env_state_done(self, env_id: int) -> bool:
         return self._env_states[env_id] == EnvState.DONE
@@ -238,6 +230,16 @@ class BaseEnvManager(object):
                 value is the cooresponding reset parameters.
         """
         assert self._closed, "Please first close the env manager"
+        try:
+            global space_log_flag
+            if space_log_flag:
+                logging.info("Env Space Information:")
+                logging.info("\tObservation Space: {}".format(self._observation_space))
+                logging.info("\tAction Space: {}".format(self._action_space))
+                logging.info("\tReward Space: {}".format(self._reward_space))
+                space_log_flag = False
+        except:
+            pass
         if reset_param is not None:
             assert len(reset_param) == len(self._env_fn)
         self._create_state()
@@ -418,6 +420,19 @@ class BaseEnvManager(object):
             replay_path = [replay_path] * self.env_num
         self._env_replay_path = replay_path
 
+    def enable_save_figure(self, env_id: int, figure_path: Union[List[str], str]) -> None:
+        """
+        Overview:
+            Set each env's replay save path.
+        Arguments:
+            - replay_path (:obj:`Union[List[str], str]`): List of paths for each environment; \
+                Or one path for all environments.
+        """
+        if isinstance(figure_path, str):
+            self._env[env_id].enable_save_figure(figure_path)
+        else:
+            raise TypeError("invalid figure_path arguments type: {}".format(type(figure_path)))
+
     def close(self) -> None:
         """
         Overview:
@@ -431,6 +446,9 @@ class BaseEnvManager(object):
             self._env_states[i] = EnvState.VOID
         self._closed = True
 
+    def reward_shaping(self, env_id: int, transitions: List[dict]) -> List[dict]:
+        return self._envs[env_id].reward_shaping(transitions)
+
     @property
     def closed(self) -> bool:
         return self._closed
@@ -457,6 +475,8 @@ class BaseEnvManagerV2(BaseEnvManager):
         """
         active_env = [i for i, s in self._env_states.items() if s == EnvState.RUN]
         obs = [self._ready_obs[i] for i in active_env]
+        if isinstance(obs[0], dict):
+            obs = [tnp.array(o) for o in obs]
         return tnp.stack(obs)
 
     def step(self, actions: List[tnp.ndarray]) -> List[tnp.ndarray]:
