@@ -9,7 +9,8 @@ from ding.envs.env_manager.gym_vector_env_manager import GymVectorEnvManager
 from gym.vector.async_vector_env import AsyncState
 
 
-@pytest.mark.unittest
+@pytest.mark.tmp
+# @pytest.mark.unittest
 class TestGymVectorEnvManager:
 
     def test_naive(self, setup_gym_vector_manager_cfg):
@@ -31,7 +32,7 @@ class TestGymVectorEnvManager:
         while not env_manager.done:
             env_id = env_manager.ready_obs.keys()
             assert all(env_manager._env_episode_count[i] < env_manager._episode_num for i in env_id)
-            action = {i: np.random.randn(4) for i in env_id}
+            action = {i: np.random.randn(3) for i in env_id}
             timestep = env_manager.step(action)
             assert len(timestep) == len(env_id)
             print('Count {}'.format(count))
