@@ -1,5 +1,5 @@
 from .context import Context, OnlineRLContext, OfflineRLContext
-from .task import Task, task
+from .task import Task, task, VoidMiddleware
 from .parallel import Parallel
 from .event_loop import EventLoop
 from .supervisor import Supervisor
