@@ -43,6 +43,8 @@ def gae_estimator(cfg: EasyDict, policy: Policy, buffer_: Optional[Buffer] = Non
         data = ctx.trajectories  # list
         data = ttorch_collate(data)
         with torch.no_grad():
+            if cfg.policy.get("cuda", False):
+                data = data.cuda()
             value = model.forward(data.obs, mode='compute_critic')['value']
             next_value = model.forward(data.next_obs, mode='compute_critic')['value']
             data.value = value
@@ -54,6 +56,8 @@ def gae_estimator(cfg: EasyDict, policy: Policy, buffer_: Optional[Buffer] = Non
         # done is bool type when acquired from env.step
         data_ = gae_data(data.value, next_value, data.reward, data.done.float(), traj_flag.float())
         data.adv = gae(data_, cfg.policy.collect.discount_factor, cfg.policy.collect.gae_lambda)
+        if cfg.policy.get("cuda", False):
+            data = data.cpu()
         if buffer_ is None:
             ctx.train_data = data
         else:
@@ -63,3 +67,15 @@ def gae_estimator(cfg: EasyDict, policy: Policy, buffer_: Optional[Buffer] = Non
         ctx.trajectories = None
 
     return _gae
+
+
+def ppof_adv_estimator(policy: Policy) -> Callable:
+
+    def _estimator(ctx: "OnlineRLContext"):
+        data = ttorch_collate(ctx.trajectories)
+        traj_flag = data.done.clone()
+        traj_flag[ctx.trajectory_end_idx] = True
+        data.traj_flag = traj_flag
+        ctx.train_data = data
+
+    return _estimator
