@@ -17,6 +17,11 @@ class OffPolicyLearner:
             the `__call__` method to execute the whole learning process.
     """
 
+    def __new__(cls, *args, **kwargs):
+        if task.router.is_active and not task.has_role(task.role.LEARNER):
+            return task.void()
+        return super(OffPolicyLearner, cls).__new__(cls)
+
     def __init__(
             self,
             cfg: EasyDict,
@@ -47,6 +52,7 @@ class OffPolicyLearner:
         """
         train_output_queue = []
         for _ in range(self.cfg.policy.learn.update_per_collect):
+            print('train_iter', ctx.train_iter)
             self._fetcher(ctx)
             if ctx.train_data is None:
                 break
