@@ -69,7 +69,7 @@ def register_runtime_fn(fn_name, runtime_name, shape):
         'ScatterConnection': ['hpc_rll.torch_utils.network.scatter_connection', 'ScatterConnection'],
         'td_lambda_error': ['hpc_rll.rl_utils.td', 'TDLambda'],
         'upgo_loss': ['hpc_rll.rl_utils.upgo', 'UPGO'],
-        'vtrace_error': ['hpc_rll.rl_utils.vtrace', 'VTrace'],
+        'vtrace_error_discrete_action': ['hpc_rll.rl_utils.vtrace', 'VTrace'],
     }
     fn_str = fn_name_mapping[fn_name]
     cls = getattr(importlib.import_module(fn_str[0]), fn_str[1])
