@@ -1,9 +1,10 @@
 # general
-from .q_learning import DQN, RainbowDQN, QRDQN, IQN, FQF, DRQN, C51DQN
+from .q_learning import DQN, RainbowDQN, QRDQN, IQN, FQF, DRQN, C51DQN, BDQ
 from .qac import QAC, DiscreteQAC
 from .pdqn import PDQN
 from .vac import VAC
 from .bc import DiscreteBC, ContinuousBC
+from .pg import PG
 # algorithm-specific
 from .ppg import PPG
 from .qmix import Mixer, QMix
@@ -18,5 +19,7 @@ from .mavac import MAVAC
 from .ngu import NGU
 from .qac_dist import QACDIST
 from .maqac import MAQAC, ContinuousMAQAC
+from .madqn import MADQN
 from .vae import VanillaVAE
 from .decision_transformer import DecisionTransformer
+from .procedure_cloning import ProcedureCloning
