@@ -1,5 +1,6 @@
 from typing import List, Any
 import torch
+import treetensor.torch as ttorch
 from ding.utils.data import default_collate
 from ding.torch_utils import to_tensor, to_ndarray, unsqueeze, squeeze
 
@@ -46,3 +47,18 @@ def single_env_forward_wrapper(forward_fn):
         return action
 
     return _forward
+
+
+def single_env_forward_wrapper_ttorch(forward_fn, cuda=True):
+
+    def _forward(obs):
+        # unsqueeze means add batch dim, i.e. (O, ) -> (1, O)
+        obs = ttorch.as_tensor(obs).unsqueeze(0)
+        if cuda and torch.cuda.is_available():
+            obs = obs.cuda()
+        action = forward_fn(obs).action
+        # squeeze means delete batch dim, i.e. (1, A) -> (A, )
+        action = action.squeeze(0).cpu().numpy()
+        return action
+
+    return _forward
