@@ -88,6 +88,8 @@ class DDPGPolicy(Policy):
         action_space='continuous',  # ['continuous', 'hybrid']
         # (bool) Whether use batch normalization for reward
         reward_batch_norm=False,
+        # (bool) Whether to enable multi-agent training setting
+        multi_agent=False,
         model=dict(
             # (bool) Whether to use two critic networks or only one.
             # Clipped Double Q-Learning for Actor-Critic in original TD3 paper(https://arxiv.org/pdf/1802.09477.pdf).
@@ -153,7 +155,10 @@ class DDPGPolicy(Policy):
     )
 
     def default_model(self) -> Tuple[str, List[str]]:
-        return 'qac', ['ding.model.template.qac']
+        if self._cfg.multi_agent:
+            return 'maqac_continuous', ['ding.model.template.maqac']
+        else:
+            return 'qac', ['ding.model.template.qac']
 
     def _init_learn(self) -> None:
         r"""
