@@ -8,6 +8,7 @@ from queue import Queue
 
 import numpy as np
 import torch
+import treetensor.torch as ttorch
 
 
 def to_device(item: Any, device: str, ignore_keys: list = []) -> Any:
@@ -29,6 +30,15 @@ def to_device(item: Any, device: str, ignore_keys: list = []) -> Any:
     """
     if isinstance(item, torch.nn.Module):
         return item.to(device)
+    elif isinstance(item, ttorch.Tensor):
+        if 'prev_state' in item:
+            prev_state = to_device(item.prev_state, device)
+            del item.prev_state
+            item = item.to(device)
+            item.prev_state = prev_state
+            return item
+        else:
+            return item.to(device)
     elif isinstance(item, torch.Tensor):
         return item.to(device)
     elif isinstance(item, Sequence):
@@ -50,6 +60,8 @@ def to_device(item: Any, device: str, ignore_keys: list = []) -> Any:
         return item
     elif item is None or isinstance(item, str):
         return item
+    elif isinstance(item, torch.distributions.Distribution):  # for compatibility
+        return item
     else:
         raise TypeError("not support item type: {}".format(type(item)))
 
@@ -408,3 +420,20 @@ def get_null_data(template: Any, num: int) -> List[Any]:
         data['reward'].zero_()
         ret.append(data)
     return ret
+
+
+def get_shape0(data):
+    if isinstance(data, torch.Tensor):
+        return data.shape[0]
+    elif isinstance(data, ttorch.Tensor):
+
+        def fn(t):
+            item = list(t.values())[0]
+            if np.isscalar(item[0]):
+                return item[0]
+            else:
+                return fn(item)
+
+        return fn(data.shape)
+    else:
+        raise TypeError("not support type: {}".format(data))
