@@ -17,6 +17,7 @@ class DistributedWriter(SummaryWriter):
         The best way is to use it in conjunction with the ``router`` to take advantage of the message \
             and event components of the router (see ``writer.plugin``).
     """
+    root = None
 
     def __init__(self, *args, **kwargs):
         self._default_writer_to_disk = kwargs.get("write_to_disk") if "write_to_disk" in kwargs else True
@@ -30,6 +31,21 @@ class DistributedWriter(SummaryWriter):
         self._is_writer = False
         self._lazy_initialized = False
 
+    @classmethod
+    def get_instance(cls, *args, **kwargs) -> "DistributedWriter":
+        """
+        Overview:
+            Get instance and set the root level instance on the first called. If args and kwargs is none,
+            this method will return root instance.
+        """
+        if args or kwargs:
+            ins = cls(*args, **kwargs)
+            if cls.root is None:
+                cls.root = ins
+            return ins
+        else:
+            return cls.root
+
     def plugin(self, router: "Parallel", is_writer: bool = False) -> "DistributedWriter":
         """
         Overview:
@@ -104,3 +120,8 @@ ready_to_parallel_fns = [
 for fn_name in ready_to_parallel_fns:
     if hasattr(DistributedWriter, fn_name):
         setattr(DistributedWriter, fn_name, enable_parallel(fn_name, getattr(DistributedWriter, fn_name)))
+
+# Examples:
+#     In main, `distributed_writer.plugin(task.router, is_writer=True)`,
+#     In middleware, `distributed_writer.record()`
+distributed_writer = DistributedWriter()
