@@ -8,7 +8,8 @@ spaceinvaders_acer_config = dict(
         evaluator_env_num=8,
         n_evaluator_episode=8,
         stop_value=int(1e6),
-        env_id='SpaceInvadersNoFrameskip-v4',
+        env_id='SpaceInvaders-v4',
+        #'ALE/SpaceInvaders-v5' is available. But special setting is needed after gym make.
         frame_stack=4,
         manager=dict(shared_memory=False, )
     ),
