@@ -79,11 +79,7 @@ cartpole_drex_dqn_create_config = dict(
     ),
     env_manager=dict(type='subprocess'),
     policy=dict(type='dqn'),
+    collector=dict(type='episode'),
 )
 cartpole_drex_dqn_create_config = EasyDict(cartpole_drex_dqn_create_config)
 create_config = cartpole_drex_dqn_create_config
-
-if __name__ == "__main__":
-    # or you can enter `ding -m serial -c cartpole_drex_dqn_config.py -s 0`
-    from ding.entry import serial_pipeline
-    serial_pipeline((main_config, create_config), seed=0)
