@@ -10,14 +10,9 @@ gym_hybrid_pdqn_config = dict(
         env_id='Moving-v0',  # ['Sliding-v0', 'Moving-v0']
         n_evaluator_episode=5,
         stop_value=1.8,
-        save_replay_gif=False,
-        replay_path_gif=None,
     ),
     policy=dict(
         cuda=True,
-        priority=False,
-        # (bool) Whether use Importance Sampling Weight to correct biased update. If True, priority must be True.
-        priority_IS_weight=False,
         discount_factor=0.99,
         nstep=1,
         model=dict(
@@ -83,4 +78,4 @@ create_config = gym_hybrid_pdqn_create_config
 if __name__ == "__main__":
     # or you can enter `ding -m serial -c gym_hybrid_pdqn_config.py -s 0`
     from ding.entry import serial_pipeline
-    serial_pipeline([main_config, create_config], seed=0)
+    serial_pipeline([main_config, create_config], seed=0, max_env_step=int(1e7))
