@@ -1,8 +1,9 @@
 from easydict import EasyDict
 
 halfcheetah_td3_config = dict(
+    exp_name='halfcheetah_td3_seed0',
     env=dict(
-        env_id='halfcheetah_td3_seed0',
+        env_id='HalfCheetah-v3',
         norm_obs=dict(use_norm=False, ),
         norm_reward=dict(use_norm=False, ),
         collector_env_num=1,
@@ -67,4 +68,4 @@ create_config = halfcheetah_td3_create_config
 if __name__ == "__main__":
     # or you can enter `ding -m serial -c halfcheetah_td3_config.py -s 0 --env-step 1e7`
     from ding.entry import serial_pipeline
-    serial_pipeline((main_config, create_config), seed=0)
\ No newline at end of file
+    serial_pipeline((main_config, create_config), seed=0)
