@@ -7,17 +7,17 @@ from functools import partial
 
 from ding.config import compile_config
 from ding.worker import BaseLearner, SampleSerialCollector, InteractionSerialEvaluator, AdvancedReplayBuffer
-from ding.envs import BaseEnvManager, DingEnvWrapper
+from ding.envs import BaseEnvManager
 from ding.envs import get_vec_env_setting, create_env_manager
 from ding.policy import DDPGPolicy
 from ding.model import QAC
 from ding.utils import set_pkg_seed
 from ding.rl_utils import get_epsilon_greedy_fn
-from dizoo.mujoco.config.ant_ddpg_config import ant_ddpg_config, ant_ddpg_create_config
+from dizoo.mujoco.envs.mujoco_env import MujocoEnv
+from dizoo.mujoco.config.ant_ddpg_config import ant_ddpg_config
 
 
-def main(rl_cfg, seed=0):
-    main_cfg, create_cfg = rl_cfg
+def main(main_cfg, seed=0):
     cfg = compile_config(
         main_cfg,
         BaseEnvManager,
@@ -26,13 +26,10 @@ def main(rl_cfg, seed=0):
         SampleSerialCollector,
         InteractionSerialEvaluator,
         AdvancedReplayBuffer,
-        create_cfg=create_cfg,
+        MujocoEnv,
         save_cfg=True
     )
 
-    create_cfg.policy.type = create_cfg.policy.type + '_command'
-    env_fn = None
-    cfg = compile_config(cfg, seed=seed, env=env_fn, auto=True, create_cfg=create_cfg, save_cfg=True)
     # Create main components: env, policy
     env_fn, collector_env_cfg, evaluator_env_cfg = get_vec_env_setting(cfg.env)
     evaluator_env = create_env_manager(cfg.env.manager, [partial(env_fn, cfg=c) for c in evaluator_env_cfg])
@@ -57,4 +54,4 @@ def main(rl_cfg, seed=0):
 
 
 if __name__ == "__main__":
-    main(rl_cfg=(ant_ddpg_config, ant_ddpg_create_config), seed=0)
+    main(ant_ddpg_config, seed=0)
