@@ -59,7 +59,7 @@ ptz_simple_spread_collaq_config = EasyDict(ptz_simple_spread_collaq_config)
 main_config = ptz_simple_spread_collaq_config
 ptz_simple_spread_collaq_create_config = dict(
     env=dict(
-        import_names=['dizoo.petting_zoo.envs.petting_zoo_env'],
+        import_names=['dizoo.petting_zoo.envs.petting_zoo_simple_spread_env'],
         type='petting_zoo',
     ),
     env_manager=dict(type='subprocess'),
